==> apm-opentracing-1.18.0-sources.jar: co/elastic/apm/opentracing/TraceContextSpanContext.java <==
/*-
 * #%L
 * Elastic APM Java agent
 * %%
 * Copyright (C) 2018 - 2020 Elastic and contributors
 * %%
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 * #L%
 */
package co.elastic.apm.opentracing;

import javax.annotation.Nullable;
import java.util.Collections;
import java.util.Map;

public class TraceContextSpanContext implements ApmSpanContext {

    // co.elastic.apm.agent.impl.transaction.TraceContext
    @Nullable
    private final Object traceContext;

    TraceContextSpanContext(@Nullable Object traceContext) {
        this.traceContext = traceContext;
    }

    @Override
    public String toTraceId() {
        // co.elastic.apm.agent.opentracing.impl.SpanContextInstrumentation$ToTraceIdInstrumentation
        return "";
    }

    @Override
    public String toSpanId() {
        // co.elastic.apm.agent.opentracing.impl.SpanContextInstrumentation$ToSpanIdInstrumentation
        return "";
    }

    @Override
    public Iterable<Map.Entry<String, String>> baggageItems() {
        return Collections.emptyList();
    }

    @Override
    @Nullable
    public Object getTraceContext() {
        return traceContext;
    }
}

==> apm-opentracing-1.52.1-sources.jar: co/elastic/apm/opentracing/TraceContextSpanContext.java <==
/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package co.elastic.apm.opentracing;

import javax.annotation.Nullable;
import java.util.Collections;
import java.util.Map;

public class TraceContextSpanContext implements ApmSpanContext {

    // co.elastic.apm.agent.impl.transaction.TraceContext
    @Nullable
    private final Object traceContext;

    TraceContextSpanContext(@Nullable Object traceContext) {
        this.traceContext = traceContext;
    }

    @Override
    public String toTraceId() {
        // co.elastic.apm.agent.opentracingimpl.SpanContextInstrumentation$ToTraceIdInstrumentation
        return "";
    }

    @Override
    public String toSpanId() {
        // co.elastic.apm.agent.opentracingimpl.SpanContextInstrumentation$ToSpanIdInstrumentation
        return "";
    }

    @Override
    public Iterable<Map.Entry<String, String>> baggageItems() {
        return Collections.emptyList();
    }

    @Override
    @Nullable
    public Object getTraceContext() {
        return traceContext;
    }
}
